Module error

Module error 

Various enums and implementations of errors for downstream use

Most error enums include an Unknown field, this is used for when there was a fatal unknown error whilst doing something in the jurastiction of that error enum, for example if there was an unknown error lexing then a ScanningError::Unknown would show

Error Hierarchy

Here is a chart of what errors are also an instance of other errors (e.g. the x error enum is inside of y error enum as X(x)):

JingoError
    ScanningError
    ParsingError

Enums

JingoError
Main error enum for all of jingo-lib, containing mostly module-level error enums
ParsingError
Errors regarding the parsing flow inside of crate::frontend::parser (also linked to crate::frontend::ast).
ScanningError
Errors for the crate::frontend::lexer module.